@@ -176,9 +176,8 @@ class NxPyDocs():
         os.system("git push %s" % url)
 
     def cleanup(self):
-        os.chdir(sys.path[0])
-        os.system("ls")
-        #os.system("rm -rf nxpydocs")
+        os.chdir("..")
+        os.system("rm -rf nxpydocs")
 
 @click.command()
 @click.option('--command',
@@ -202,15 +201,15 @@ class NxPyDocs():
 @click.option('--repo',
     prompt='Git Repository',
     help=('The Git repository to send the output files'),
-    required=False)
+    required=False,envvar="REPO")
 @click.option('--username',
     prompt='Git Repository Username',
     help=('The Git repository username'),
-    required=False)
+    required=False,envvar="USERNAME")
 @click.option('--token',
     prompt='Git Repository token',
     help=('The Git repository token'),
-    required=False)    
+    required=False,hide_input=True,envvar="TOKEN")    
 def cli(command,
         filetype,
         repo,
